
These changes are listed in decreasing version number order.


Release 0.3
-----------

Release date was |today|

+ migration to python 3 (by dropping python 2 support)
+ more documentation
+ adding rest api support (incl. flask web service demo)
+ adding storage backend (currently by file or sqllite3)


Release 0.2
-----------

Release date was December 31th, 2017


Release 0.1
-----------

Release date was July 7th, 2017
